==> western-world-3.0.133.tgz: package/src/western-world.utils.constants.js <==
export const ORIGINAL_WESTERN_WORLD_WIDTH = 3029;
export const ORIGINAL_WESTERN_WORLD_HEIGHT = 1306;

export const backgroundsArr = ['background.svg', 'forest.svg', 'start.svg', 'desert.svg', 'progress.svg'];
export const othersFiles = [
  ...backgroundsArr,
  'flag.svg',
  'colony-arrows.svg',
  'background-top-elements.svg',
  'circle_is_done.svg',
  'star.svg',
];

export const languageSvgStyles = `
  .en [id^="en"] {display: block}
  .ru [id^="ru"] {display: block}
  .uk [id^="uk"] {display: block}
  .ru [id^="ruuk"] {display: block}
  .uk [id^="ruuk"] {display: block}
`;

//TODO Temporary till Chrome fixes bug with SVG + animation + Mask;
const temporaryStylesFix = `
  .animated use.use-mask {
    stroke-width: 0 !important;
  }
`;

export const maskStyles = `
  use.use-mask {
    stroke-width: 200px;
    stroke: black;
    fill: white;
  }
  use.use-border {
    stroke-width: 100px;
    stroke: white;
    fill: black;
  }
  use.use-additional-mask {
    fill: white;
    stroke: white;
  }

  ${temporaryStylesFix}
`;

export const myFlagSvgStyles = `
  .flag_st0 {fill: #00ff2f !important}
`;

export const enemyFlagSvgStyles = `
  .flag_st0 {fill: #f44b3f !important}
`;

export const flagStarsStyles = {
  0: '',
  1: `
    #star-1 {display: block}
  `,
  2: `
    #star-1, #star-2 {display: block}
  `,
  3: `
  #star-1, #star-2, #star-3 {display: block}
  `,
  4: `
  #star-1, #star-2, #star-3, #star-4 {display: block}
  `,
  5: `
  #star-1, #star-2, #star-3, #star-4, #star-5 {display: block}
  `,
};

==> western-world-3.0.140.tgz: package/src/western-world.utils.constants.js <==
export const ORIGINAL_WESTERN_WORLD_WIDTH = 3029;
export const ORIGINAL_WESTERN_WORLD_HEIGHT = 1306;

export const backgroundsArr = ['background.svg', 'forest.svg', 'start.svg', 'desert.svg', 'progress.svg'];
export const othersFiles = [
  ...backgroundsArr,
  'flag.svg',
  'colony-arrows.svg',
  'background-top-elements.svg',
  'circle_is_done.svg',
  'star.svg',
];

export const languageSvgStyles = `
  .en [id^="en"] {display: block}
  .ru [id^="ru"] {display: block}
  .uk [id^="uk"] {display: block}
  .ru [id^="ruuk"] {display: block}
  .uk [id^="ruuk"] {display: block}
`;

//TODO Temporary till Chrome fixes bug with SVG + animation + Mask;
export const temporaryStylesFix = `
  .animated use.use-mask {
    stroke-width: 0 !important;
  }
`;

export const maskStyles = `
  use.use-mask {
    stroke-width: 200px;
    stroke: black;
    fill: white;
  }
  use.use-border {
    stroke-width: 100px;
    stroke: white;
    fill: black;
  }
  use.use-additional-mask {
    fill: white;
    stroke: white;
  }
`;

export const myFlagSvgStyles = `
  .flag_st0 {fill: #00ff2f !important}
`;

export const enemyFlagSvgStyles = `
  .flag_st0 {fill: #f44b3f !important}
`;

export const flagStarsStyles = {
  0: '',
  1: `
    #star-1 {display: block}
  `,
  2: `
    #star-1, #star-2 {display: block}
  `,
  3: `
  #star-1, #star-2, #star-3 {display: block}
  `,
  4: `
  #star-1, #star-2, #star-3, #star-4 {display: block}
  `,
  5: `
  #star-1, #star-2, #star-3, #star-4, #star-5 {display: block}
  `,
};
